@@ -31,9 +31,9 @@ print.bride <- function(x, ...) {
     cat("\nCall:\n")
     print(x$call)
     cat("\n")
-    cat(sprintf("REL = %1.4f +/- %1.4f\n", x$rel2, sqrt(x$rel2v)))
-    cat(sprintf("RES = %1.4f +/- %1.4f\n", x$res2, sqrt(x$res2v)))
-    cat(sprintf("UNC = %1.4f +/- %1.4f\n", x$unc2, sqrt(x$unc2v)))
+    cat(sprintf("REL = %1.4f +/- %1.4f\n", x$rel2, sqrt(x$rel2.var)))
+    cat(sprintf("RES = %1.4f +/- %1.4f\n", x$res2, sqrt(x$res2.var)))
+    cat(sprintf("UNC = %1.4f +/- %1.4f\n", x$unc2, sqrt(x$unc2.var)))
     cat("\n")
     cat(sprintf("REL - RES + UNC = %1.4f\n", x$rel2-x$res2+x$unc2))
     cat(sprintf("Br = %1.4f\n", mean( (x$y-x$p)^2 )))
